import random
import time
from pathlib import Path
from subprocess import run

import typer

app = typer.Typer()

LOOP = True


@app.command("set")
def set_wallpaper(wallpaper_path: str):
    if Path(wallpaper_path).is_dir():
        wallpapers = list(Path(wallpaper_path).glob("*"))

        if wallpapers:
            wallpaper = random.choice(wallpapers)
            run(f"feh --bg-scale {wallpaper}", shell=True)
            typer.echo(f"Wallpaper set to: {wallpaper}")
        else:
            typer.echo("No wallpapers found in the directory")
    elif Path(wallpaper_path).is_file():
        run(f"feh --bg-scale {wallpaper_path}", shell=True)
        typer.echo(f"Wallpaper set to: {wallpaper_path}")
    else:
        typer.echo("No wallpaper file is found")


@app.command("random")
def random_wallpaper(wallpaper_dir: str, timeout: int = 1800, max_changes: int = 0):
    def _change_wallpaper():
        set_wallpaper(wallpaper_dir)
        time.sleep(timeout)

    if max_changes == 0:
        while True:
            _change_wallpaper()
    else:
        for _ in range(max_changes):
            _change_wallpaper()


if __name__ == "__main__":
    app()



import typer

from ebenezer.commands.helpers import run_command

app = typer.Typer()


@app.command("level")
def backlight_level():
    level = _do_backlight_level()
    typer.echo(level)


@app.command("up")
def backlight_up():
    _do_backlight_up()
    typer.echo("Backlight increased by 10%")


@app.command("down")
def backlight_down():
    _do_backlight_down()
    typer.echo("Backlight decreased by 10%")


@app.command("set")
def backlight_set(level: int):
    _do_backlight_set(level)
    typer.echo(f"Backlight changed to {level}%")


def _do_backlight_level() -> str:
    command = "brightnessctl | grep -oP '\\d+%'"
    return run_command(command)


def _do_backlight_up():
    command = "brightnessctl set 10%+"
    run_command(command)


def _do_backlight_down():
    command = "brightnessctl set 10%-"
    run_command(command)


def _do_backlight_set(level: int):
    command = f"brightnessctl set {level}%"
    run_command(command)


if __name__ == "__main__":
    app()



import unittest

from ebenezer.commands.volume import run_command


class TestHelpers(unittest.TestCase):
    def test_run_command(self):
        result = run_command("echo 50%")
        self.assertEqual(result, "50%")


if __name__ == "__main__":
    unittest.main()



import typer

from ebenezer.rofi.modals.confirm import main as run_confirm
from ebenezer.rofi.powermenu.main import main as run_powermenu
from ebenezer.rofi.wallpaper_menu.main import main as run_wallpaper_menu
from ebenezer.ui.settings.main import main as run_settings

app = typer.Typer()


@app.command("powermenu")
def powermenu():
    run_powermenu()


@app.command("confirm")
def confirm():
    run_confirm()


@app.command("wallpaper_menu")
def confirm():
    run_wallpaper_menu()


@app.command("settings")
def confirm():
    run_settings()


if __name__ == "__main__":
    app()



import unittest
from unittest.mock import patch

from typer.testing import CliRunner

from ebenezer.commands.ui import app

runner = CliRunner()


class TestUICommands(unittest.TestCase):

    @patch("ebenezer.commands.ui.run_powermenu")
    def test_powermenu(self, mock_run_powermenu):
        result = runner.invoke(app, ["powermenu"])
        mock_run_powermenu.assert_called_once()
        self.assertEqual(result.exit_code, 0)

    @patch("ebenezer.commands.ui.run_confirm")
    def test_confirm(self, mock_run_confirm):
        result = runner.invoke(app, ["confirm"])
        mock_run_confirm.assert_called_once()
        self.assertEqual(result.exit_code, 0)

    @patch("ebenezer.commands.ui.run_wallpaper_menu")
    def test_wallpaper_menu(self, mock_run_wallpaper_menu):
        result = runner.invoke(app, ["wallpaper_menu"])
        mock_run_wallpaper_menu.assert_called_once()
        self.assertEqual(result.exit_code, 0)


if __name__ == "__main__":
    unittest.main()



import unittest
from unittest.mock import MagicMock, patch

from typer.testing import CliRunner

from ebenezer.commands.wallpaper import app

runner = CliRunner()


class TestWallpaperCommands(unittest.TestCase):

    @patch("ebenezer.commands.wallpaper.run")
    @patch("ebenezer.commands.wallpaper.typer.echo")
    @patch("ebenezer.commands.wallpaper.Path")
    @patch("ebenezer.commands.wallpaper.random.choice")
    def test_set_wallpaper_with_directory(
        self, mock_random_choice, mock_path, mock_typer_echo, mock_run
    ):
        # Mock the Path object and its methods
        mock_path_obj = MagicMock()
        mock_path.return_value = mock_path_obj
        mock_path_obj.is_dir.return_value = True
        mock_wallpaper = MagicMock()
        mock_path_obj.glob.return_value = [mock_wallpaper]
        mock_random_choice.return_value = mock_wallpaper

        # Invoke the set_wallpaper command
        result = runner.invoke(app, ["set", "/path/to/wallpapers"])

        # Assertions
        mock_path.assert_called_with("/path/to/wallpapers")
        mock_path_obj.is_dir.assert_called_once()
        mock_path_obj.glob.assert_called_once_with("*")
        mock_random_choice.assert_called_once_with([mock_wallpaper])
        mock_run.assert_called_once_with(f"feh --bg-scale {mock_wallpaper}", shell=True)
        mock_typer_echo.assert_called_once_with(f"Wallpaper set to: {mock_wallpaper}")

    @patch("ebenezer.commands.wallpaper.run")
    @patch("ebenezer.commands.wallpaper.typer.echo")
    @patch("ebenezer.commands.wallpaper.Path")
    def xtest_set_wallpaper_with_file(self, mock_path, mock_typer_echo, mock_run):
        mock_path_obj = MagicMock()
        mock_path.return_value = mock_path_obj
        mock_path_obj.is_file.return_value = True

        result = runner.invoke(app, ["set", "/path/to/wallpaper.jpg"])

        mock_path.assert_called_with("/path/to/wallpaper.jpg")
        mock_path_obj.is_file.assert_called_once()
        mock_run.assert_called_once_with(
            "feh --bg-scale /path/to/wallpaper.jpg", shell=True
        )
        mock_typer_echo.assert_called_once_with(
            "Wallpaper set to: /path/to/wallpaper.jpg"
        )

    @patch("ebenezer.commands.wallpaper.run")
    @patch("ebenezer.commands.wallpaper.typer.echo")
    @patch("ebenezer.commands.wallpaper.Path")
    def test_set_wallpaper_with_invalid_path(
        self, mock_path, mock_typer_echo, mock_run
    ):
        # Mock the Path object and its methods
        mock_path_obj = MagicMock()
        mock_path.return_value = mock_path_obj
        mock_path_obj.is_dir.return_value = False
        mock_path_obj.is_file.return_value = False

        # Invoke the set_wallpaper command
        result = runner.invoke(app, ["set", "/invalid/path"])

        # Assertions
        mock_path.assert_called_with("/invalid/path")
        mock_path_obj.is_dir.assert_called_once()
        mock_path_obj.is_file.assert_called_once()
        mock_typer_echo.assert_called_once_with("No wallpaper file is found")
        mock_run.assert_not_called()

    @patch("ebenezer.commands.wallpaper.set_wallpaper")
    @patch("time.sleep")
    def test_random_wallpaper(self, mock_sleep, mock_set_wallpaper):
        mock_sleep.side_effect = lambda x: None

        runner.invoke(
            app, ["random", "/path/to/wallpapers", "--timeout", "1", "--max-changes", 1]
        )
        mock_sleep.assert_called_with(1)

        mock_set_wallpaper.assert_called_with("/path/to/wallpapers")
        mock_sleep.assert_called_with(1)


if __name__ == "__main__":
    unittest.main()
